@@ -93,7 +93,11 @@ class Scope:
     def _get_accounts_for_service (self, service):
         """Get online accounts matching the scope service"""
         self._accounts = []
-        self._account_manager = Accounts.Manager.new_for_service_type("sharing")
+        try:
+            self._account_manager = Accounts.Manager.new_for_service_type("sharing")
+        except TypeError as e:
+            print ("Error (facebook): Unable to initialise accounts manager: %s" % e)
+            return
         self._account_manager.connect("enabled-event", self._on_enabled_event)
         self._account_manager.connect("account-deleted", self._on_deleted_event)
         for account_service in self._account_manager.get_enabled_account_services():
