@@ -50,7 +50,7 @@ class Scope:
         self._scope.connect("notify::active", self.on_lens_active)
         self._scope.props.sources.connect("notify::filtering", self.on_filtering_changed)
         self._scope.connect('preview-uri', self.on_preview_uri)
-        self._scope.provides_personal_content=True
+        self._scope.props.provides_personal_content=True
         source_name = SOURCE
         self.last_db_change = None
         self._sources_options = []
